@@ -23,8 +23,10 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
 
     qputenv("DXCB_FAKE_PLATFORM_NAME_XCB", "true");
+    qDebug() << "Set DXCB_FAKE_PLATFORM_NAME_XCB=true";
     //禁用GPU
     qputenv("QTWEBENGINE_CHROMIUM_FLAGS", "--disable-gpu");
+    qDebug() << "Set QTWEBENGINE_CHROMIUM_FLAGS=--disable-gpu";
 //    qputenv("QTWEBENGINE_REMOTE_DEBUGGING", "7777");
 
 #ifdef LINGLONG_BUILD
@@ -48,30 +50,44 @@ int main(int argc, char **argv)
 #else
     if (!Utils::judgeWayLand()) {
         qputenv("QTWEBENGINE_CHROMIUM_FLAGS", "--single-process");
+        qDebug() << "Non-Wayland environment, set single-process mode";
+    } else {
+        qDebug() << "Wayland environment detected";
     }
 #endif
 
     // 增加路径以搜索主机应用和玲珑应用中的帮助手册
     if (qEnvironmentVariableIsSet("LINGLONG_APPID")) {
+        qDebug() << "Running in Linglong container environment";
         QByteArray paths = qgetenv("XDG_DATA_DIRS");
+        qDebug() << "Original XDG_DATA_DIRS:" << paths;
         paths.append(":/run/host/rootfs/usr/share:/run/host/rootfs/var/lib/linglong/entries/share");
         qputenv("XDG_DATA_DIRS", paths);
     }
+    qDebug() << "XDG_DATA_DIRS set to:" << qgetenv("XDG_DATA_DIRS");
 
     // 后端服务dmanHelper自检，若前端dman应用不存在，则后端dmanHelper退出
     DManWatcher watcher;
     ManualSearchProxy search_obj;
     ManualSearchAdapter adapter(&search_obj);
 
-    qDebug() << Dtk::Core::DLogManager::getlogFilePath();
+    QString logPath = Dtk::Core::DLogManager::getlogFilePath();
+    qDebug() << "Log file path:" << logPath;
 
+    qDebug() << "Initializing OpenGL context";
     QOpenGLContext ctx;
     QSurfaceFormat fmt;
     fmt.setRenderableType(QSurfaceFormat::OpenGL);
+    qDebug() << "Setting OpenGL renderable type";
     ctx.setFormat(fmt);
+    qDebug() << "Creating OpenGL context";
     ctx.create();
     if (!ctx.isValid()) {
+        qWarning() << "OpenGL context invalid, fallback to OpenGLES";
         fmt.setRenderableType(QSurfaceFormat::OpenGLES);
+        qDebug() << "OpenGLES format set, profile:" << fmt.profile();
+    } else {
+        qDebug() << "OpenGL context created successfully";
     }
     fmt.setDefaultFormat(fmt);
     fmt.setProfile(QSurfaceFormat::CoreProfile);
@@ -79,6 +95,7 @@ int main(int argc, char **argv)
     Dtk::Core::DLogManager::registerFileAppender();
     Dtk::Core::DLogManager::registerConsoleAppender();
 
+    qInfo() << "Starting DBus service registration";
     QDBusConnection conn = QDBusConnection::sessionBus();
     if (!conn.registerService(kManualSearchService)
             || !conn.registerObject(kManualSearchIface, &search_obj)) {
@@ -87,8 +104,12 @@ int main(int argc, char **argv)
     } else {
         qDebug() << "dmanHelper register dbus service success!";
     }
+    qInfo() << "Successfully registered DBus service:" << kManualSearchService
+           << "and object path:" << kManualSearchIface;
 
     helperManager obj;
 
-    return app.exec();
+    int ret = app.exec();
+    qInfo() << "dmanHelper exiting with code:" << ret;
+    return ret;
 }
