@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "SearchAdaptor.h"
+#include "base/ddlog.h"
 #include <QtCore/QMetaObject>
 #include <QtCore/QByteArray>
 #include <QtCore/QList>
@@ -18,20 +19,23 @@
 SearchAdaptor::SearchAdaptor(QObject *parent)
     : QDBusAbstractAdaptor(parent)
 {
-    // constructor
+    qCDebug(app) << "SearchAdaptor constructor called";
     setAutoRelaySignals(true);
+    qCDebug(app) << "Auto relay signals enabled";
 }
 
 SearchAdaptor::~SearchAdaptor()
 {
-    // destructor
+    qCDebug(app) << "Destroying SearchAdaptor instance";
 }
 
 bool SearchAdaptor::ManualExists(const QString &in0)
 {
+    qCDebug(app) << "ManualExists method called with parameter:" << in0;
     // handle method call com.deepin.Manual.Search.ManualExists
     bool out0;
     QMetaObject::invokeMethod(parent(), "ManualExists", Q_RETURN_ARG(bool, out0), Q_ARG(QString, in0));
+    qCDebug(app) << "ManualExists result:" << out0;
     return out0;
 }
 
