@@ -5,6 +5,7 @@
 #include "filewatcher.h"
 #include "base/utils.h"
 #include "base/consts.h"
+#include "base/ddlog.h"
 
 #include <QDir>
 #include <QDebug>
@@ -15,12 +16,14 @@ fileWatcher::fileWatcher(QObject *parent)
     , watcherObj(new QFileSystemWatcher(this))
     , timerObj(new QTimer(this))
 {
+    qCDebug(app) << "Initializing file watcher";
     timerObj->setSingleShot(true);
     timerObj->setInterval(3 * 1000);
     connect(timerObj, &QTimer::timeout, this, &fileWatcher::onTimerOut);
     connect(watcherObj, &QFileSystemWatcher::fileChanged, this, &fileWatcher::onChangeFile);
     connect(watcherObj, &QFileSystemWatcher::directoryChanged, this, &fileWatcher::onChangeDirSlot);
     monitorFile();
+    qCDebug(app) << "File watcher initialized successfully";
 }
 
 void fileWatcher::setFileMap(QMap<QString, QString> &map)
@@ -40,26 +43,33 @@ void fileWatcher::checkMap(QMap<QString, QString> &mapOld, QMap<QString, QString
 {
     QList<QString> listOldMd = mapOld.keys();
     QList<QString> listNowMd = mapNow.keys();
+    qCDebug(app) << "checkMap listNowMd:" << listNowMd;
+    qCDebug(app) << "checkMap listOldMd:" << listOldMd;
 
     for (const QString &mdPath : listOldMd) {
         if (!listNowMd.contains(mdPath)) {
             deleteList.append(mdPath);
+            qCDebug(app) << "Delete file:" << mdPath;
         }
     }
 
     for (const QString &mdPath : listNowMd) {
         if (!listOldMd.contains(mdPath)) {
             addList.append(mdPath);
+            qCDebug(app) << "Add file:" << mdPath;
         } else if (mapOld.value(mdPath) != mapNow.value(mdPath)) {
             addList.append(mdPath);
+            qCDebug(app) << "Modify file:" << mdPath;
         }
     }
 
     if (!addList.isEmpty()) {
+        qCDebug(app) << "Add list:" << addList;
         for (const QString &file : addList) {
             addTime.append(mapNow.value(file));
         }
     }
+    qCDebug(app) << "Delete list:" << deleteList;
 }
 
 
@@ -68,20 +78,26 @@ void fileWatcher::checkMap(QMap<QString, QString> &mapOld, QMap<QString, QString
  */
 void fileWatcher::monitorFile()
 {
+    qCDebug(app) << "monitorFile";
     watcherObj->removePaths(watcherObj->directories());
     watcherObj->removePaths(watcherObj->files());
 
     QStringList listMonitorFile;
     QStringList listModule;
     QStringList  assetsPathList = Utils::getSystemManualDir();
+    qCDebug(app) << "Found" << assetsPathList.size() << "manual directories to monitor";
+
     foreach (auto assetsPath, assetsPathList) {
+        qCDebug(app) << "Processing manual directory:" << assetsPath;
         listModule.append(assetsPath);
+
         //新文案结构 /usr/share/deepin-manual/manual-assets/[application | system]/appName/appNameT/land/*_appNameT.md
         for (const QString &type : QDir(assetsPath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
             //监控资源文件夹
             if (type == "system" || type == "application") {
                 QString typePath = assetsPath + "/" + type;
                 listModule.append(typePath);
+                qCDebug(app) << "Processing manual type:" << typePath;
                 //监控资源文件夹
                 for (QString &module : QDir(typePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                     //./manual-assets/application(system)/appName
@@ -90,25 +106,30 @@ void fileWatcher::monitorFile()
                     QStringList listAppNameT = QDir(modulePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs);
 
                     if (listAppNameT.count() != 1) {
-                        qCritical() << Q_FUNC_INFO << modulePath  << "：there are more folders..:" << listAppNameT.count();
+                         qCCritical(app) << modulePath  << "：there are more folders..:" << listAppNameT.count();
                         continue;
                     }
                     //./manual-assets/application(system)/appName/appNameT
                     QString appPath = modulePath + "/" + listAppNameT.at(0);
                     listModule.append(appPath);
+                    qCDebug(app) << "Processing app:" << appPath;
                     for (QString &lang : QDir(appPath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                         if (lang == "zh_CN" || lang == "en_US") {
                             //./manual-assets/application(system)/appName/appNameT/lang
                             QString langPath = appPath + "/" + lang;
                             listModule.append(langPath);
+                            qCDebug(app) << "Processing language:" << langPath;
                             for (QString &mdFile : QDir(langPath).entryList(QDir::Files)) {
                                 if (mdFile.endsWith("md")) {
                                     //./manual-assets/application(system)/appName/appNameT/lang/md
                                     QString strMd = langPath + "/" + mdFile;
                                     QFileInfo fileinfo(strMd);
                                     if (fileinfo.isSymLink()) {
-                                        listMonitorFile.append(fileinfo.symLinkTarget());
+                                        QString target = fileinfo.symLinkTarget();
+                                        qCDebug(app) << "Adding symlink:" << strMd << "->" << target;
+                                        listMonitorFile.append(target);
                                     } else {
+                                        qCDebug(app) << "Adding markdown file:" << strMd;
                                         listMonitorFile.append(strMd);
                                     }
                                 }
@@ -119,22 +140,28 @@ void fileWatcher::monitorFile()
             }
         }
 
-//旧文案结构兼容  /usr/share/deepin-manual/manual-assets/[professional | server]/appName/lang/index.md
+        //旧文案结构兼容  /usr/share/deepin-manual/manual-assets/[professional | server]/appName/lang/index.md
 #if 1
         for (const QString &system : QDir(assetsPath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
             if (systemType.contains(system)) {
                 QString typePath = assetsPath + "/" + system;
                 listModule.append(typePath);
+                qCDebug(app) << "Processing legacy system:" << typePath;
+
                 for (QString &module : QDir(typePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                     QString modulePath = typePath + "/" + module;
                     listModule.append(typePath);
                     for (QString &lang : QDir(modulePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                         if (lang == "zh_CN" || lang == "en_US") {
                             QString strMd = modulePath + "/" + lang + "/index.md";
+                            qCDebug(app) << "Adding legacy markdown file:" << strMd;
                             QFileInfo fileinfo(strMd);
                             if (fileinfo.isSymLink()) {
-                                listMonitorFile.append(fileinfo.symLinkTarget());
+                                QString target = fileinfo.symLinkTarget();
+                                qCDebug(app) << "Adding legacy symlink:" << strMd << "->" << target;
+                                listMonitorFile.append(target);
                             } else {
+                                qCDebug(app) << "Adding legacy markdown file:" << strMd;
                                 listMonitorFile.append(strMd);
                             }
                         }
@@ -147,13 +174,16 @@ void fileWatcher::monitorFile()
         //监控模块资源文件夹
         if (!listModule.isEmpty()) {
             watcherObj->addPaths(listModule);
+            qCDebug(app) << "Adding" << listModule.size() << "directories to watch";
         }
+        
         //监控资源文件
         if (!listMonitorFile.isEmpty()) {
             watcherObj->addPaths(listMonitorFile);
+            qCDebug(app) << "Adding" << listMonitorFile.size() << "files to watch";
         }
     }
-    qDebug() << Q_FUNC_INFO << "WatchAllFiles... ...";
+    qCDebug(app) << "WatchAllFiles... ...";
 }
 
 /**
@@ -163,11 +193,13 @@ void fileWatcher::monitorFile()
  */
 void fileWatcher::onChangeFile(const QString &path)
 {
-    qDebug() << Q_FUNC_INFO << path;
+    qCDebug(app) << path;
     QTimer::singleShot(50, [ = ]() {
         watcherObj->addPath(path);
+        qCDebug(app) << "Adding" << path << "to watch";
     });
 
+    qCDebug(app) << "Timer triggered, checking file changes";
     timerObj->start();
 }
 
@@ -177,12 +209,13 @@ void fileWatcher::onChangeFile(const QString &path)
  */
 void fileWatcher::onChangeDirSlot(const QString &path)
 {
-    qDebug() << Q_FUNC_INFO << path;
+    qCDebug(app) << path;
     timerObj->start();
 }
 
 void fileWatcher::onTimerOut()
 {
+    qCDebug(app) << "Timer triggered, checking file changes";
     QMap<QString, QString> mapNow;
     QStringList  assetsPathList = Utils::getSystemManualDir();
     foreach (auto assetsPath, assetsPathList) {
@@ -197,7 +230,7 @@ void fileWatcher::onTimerOut()
                     QStringList listAppNameT = QDir(modulePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs);
 
                     if (listAppNameT.count() != 1) {
-                        qCritical() << Q_FUNC_INFO << modulePath  << "：there are more folders..:" << listAppNameT.count();
+                        qCCritical(app) << modulePath  << "：there are more folders..:" << listAppNameT.count();
                         continue;
                     }
                     //./manual-assets/application(system)/appName/appNameT
@@ -206,14 +239,17 @@ void fileWatcher::onTimerOut()
                         if (lang == "zh_CN" || lang == "en_US") {
                             //./manual-assets/application(system)/appName/appNameT/lang
                             QString langPath = appPath + "/" + lang;
+                            qCDebug(app) << "Checking file changes:" << langPath;
                             for (QString &mdFile : QDir(langPath).entryList(QDir::Files)) {
                                 if (mdFile.endsWith("md")) {
                                     //./manual-assets/application(system)/appName/appNameT/lang/md
                                     QString strMd = langPath + "/" + mdFile;
+                                    qCDebug(app) << "Checking file changes:" << strMd;
                                     QFileInfo fileInfo(strMd);
                                     if (fileInfo.exists()) {
                                         QString modifyTime = fileInfo.lastModified().toString("yyyy-MM-dd hh:mm:ss.zzz");
                                         mapNow.insert(strMd, modifyTime);
+                                        qCDebug(app) << "File changed:" << strMd << "modifyTime:" << modifyTime;
                                     }
                                 }
                             }
@@ -228,15 +264,18 @@ void fileWatcher::onTimerOut()
         for (const QString &system : QDir(assetsPath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
             if (systemType.contains(system)) {
                 QString typePath = assetsPath + "/" + system;
+                qCDebug(app) << "Checking file changes:" << typePath;
                 for (QString &module : QDir(typePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                     QString modulePath = typePath + "/" + module;
                     for (QString &lang : QDir(modulePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                         if (lang == "zh_CN" || lang == "en_US") {
                             QString strMd = modulePath + "/" + lang + "/index.md";
+                            qCDebug(app) << "Checking file changes:" << strMd;
                             QFileInfo fileInfo(strMd);
                             if (fileInfo.exists()) {
                                 QString modifyTime = fileInfo.lastModified().toString("yyyy-MM-dd hh:mm:ss.zzz");
                                 mapNow.insert(strMd, modifyTime);
+                                qCDebug(app) << "File changed:" << strMd << "modifyTime:" << modifyTime;
                             }
                         }
                     }
@@ -249,13 +288,16 @@ void fileWatcher::onTimerOut()
     if (fileInfo.exists()) {
         QString modifyTime = fileInfo.lastModified().toString("yyyy-MM-dd hh:mm:ss.zzz");
         mapNow.insert(kVideoConfigPath, modifyTime);
+        qCDebug(app) << "File changed:" << kVideoConfigPath << "modifyTime:" << modifyTime;
     }
 
     QStringList deleteList;
     QStringList addList;
     QStringList addTime;
+    qCDebug(app) << "Checking file changes";
     checkMap(mapOld, mapNow, deleteList, addList, addTime);
     mapOld = mapNow;
     emit filelistChange(deleteList, addList, addTime);
     monitorFile();
+    qCDebug(app) << "File change processing completed";
 }
