@@ -4,6 +4,7 @@
 
 #include "view/image_viewer_proxy.h"
 #include "view/widget/image_viewer.h"
+#include "base/ddlog.h"
 
 #include <DLog>
 #include <QUrl>
@@ -13,10 +14,12 @@ ImageViewerProxy::ImageViewerProxy(ImageViewer *viewer,
     : QObject(parent)
     , viewer_(viewer)
 {
+    qCDebug(app) << "ImageViewerProxy constructor called";
 }
 
 ImageViewerProxy::~ImageViewerProxy()
 {
+    qCDebug(app) << "ImageViewerProxy destructor called";
 }
 
 /**
@@ -26,8 +29,10 @@ ImageViewerProxy::~ImageViewerProxy()
  */
 void ImageViewerProxy::open(const QString &filepath)
 {
+    qCDebug(app) << "ImageViewerProxy::open() called with file:" << filepath;
     Q_ASSERT(viewer_ != nullptr);
     Q_UNUSED(filepath);
+    qCDebug(app) << "Opening image file:" << filepath;
     viewer_->open(filepath);
 }
 
@@ -38,5 +43,8 @@ void ImageViewerProxy::open(const QString &filepath)
  */
 void ImageViewerProxy::openHttpUrl(const QString &httpUrl)
 {
-    QDesktopServices::openUrl(QUrl(httpUrl));
+    qCDebug(app) << "Opening external URL:" << httpUrl;
+    if (!QDesktopServices::openUrl(QUrl(httpUrl))) {
+        qCWarning(app) << "Failed to open URL:" << httpUrl;
+    }
 }
