@@ -3,16 +3,19 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "view/title_bar_proxy.h"
+#include "base/ddlog.h"
 
 TitleBarProxy::TitleBarProxy(QObject *parent)
     : QObject(parent)
 {
+    qCDebug(app) << "TitleBarProxy constructor called";
     m_webWindow = static_cast<WebWindow *>(parent);
     m_first = 0;
 }
 
 TitleBarProxy::~TitleBarProxy()
 {
+    qCDebug(app) << "TitleBarProxy destructor called";
 }
 
 /**
@@ -22,6 +25,7 @@ TitleBarProxy::~TitleBarProxy()
  */
 void TitleBarProxy::setBackwardButtonActive(bool active)
 {
+    qCDebug(app) << "Setting backward button active state:" << active;
     m_webWindow->cancelTextChanged();
     m_webWindow->m_backButton->setEnabled(active);
     m_webWindow->updateBtnBox();
@@ -34,6 +38,7 @@ void TitleBarProxy::setBackwardButtonActive(bool active)
  */
 void TitleBarProxy::setForwardButtonActive(bool active)
 {
+    qCDebug(app) << "Setting forward button active state:" << active;
     m_webWindow->m_forwardButton->setEnabled(active);
     m_webWindow->updateBtnBox();
 }
