@@ -1,18 +1,20 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" sourcelanguage="en_US" language="sl">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="sl" sourcelanguage="en_US">
 <context>
     <name>ManualProxy</name>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="322"/>
+        <location filename="../src/view/manual_proxy.cpp" line="363"/>
         <source>Learn Basic Operations</source>
         <translation>Učite osnovne operacije</translation>
     </message>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="324"/>
+        <location filename="../src/view/manual_proxy.cpp" line="366"/>
         <source>Common Application Libraries</source>
         <translation>Obične aplikacijske knjižnice</translation>
     </message>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="326"/>
+        <location filename="../src/view/manual_proxy.cpp" line="369"/>
         <source>Desktop Environment</source>
         <translation>Namizno okolje</translation>
     </message>
@@ -20,94 +22,94 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="291"/>
         <source>Search for &quot;%1&quot; in the full text</source>
         <translation>Poišči &quot;%1&quot; v celotnem besedilu</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="301"/>
+        <location filename="../src/view/web_window.cpp" line="363"/>
         <source>The content was updated</source>
         <translation>Vsebina je bila posodobljena</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="624"/>
+        <location filename="../src/view/web_window.cpp" line="767"/>
         <source>Search</source>
         <translation>Išči</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="627"/>
-        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
+        <location filename="../src/view/web_window.cpp" line="771"/>
         <source>Support</source>
         <translation>Podpora</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="836"/>
+        <location filename="../src/view/web_window.cpp" line="1038"/>
         <source>Copy</source>
         <translation>Kopija</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
         <source>Quick Start</source>
         <translation>Hitro začetek</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
         <source>Video Guide</source>
         <translation>Videografski vodič</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="23"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
         <source>System</source>
         <translation>Sistem</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="24"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
         <source>Applications</source>
         <translation>Programi</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
         <source>No search results</source>
         <translation>Ni rezultatov iskanj</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
         <source>Home</source>
         <translation>Domov</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
         <source>  result</source>
         <translation>rezultat</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
         <source>  results</source>
         <translation>rezultati</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
         <source>Click to view </source>
         <translation>Kliknite za prikaz</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
         <source>View all</source>
         <translation>Prikaži vse</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
         <source>App Store</source>
         <translation>Trgovina aplikacij</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="105"/>
+        <location filename="../src/app/dman.cpp" line="136"/>
         <source>Manual</source>
         <translation>Priročnik</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="106"/>
+        <location filename="../src/app/dman.cpp" line="137"/>
         <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
         <translation>Priročnik je zasnovan za pomoč uporabnikom pri učenju rabe operacijskega sistema in njegovih programov. Vsebuje specifična navodila in opise funkcij.</translation>
     </message>
@@ -115,14 +117,14 @@
 <context>
     <name>WebWindow</name>
     <message>
-        <location filename="../src/view/web_window.cpp" line="765"/>
+        <location filename="../src/view/web_window.cpp" line="952"/>
         <source>Ctrl+Alt+F</source>
         <translation>Ctrl+Alt+F</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="780"/>
+        <location filename="../src/view/web_window.cpp" line="969"/>
         <source>Ctrl+F</source>
         <translation>Ctrl+F</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
